==> compton-conf_0.1.0+20151226.orig.tar.xz: compton-conf-0.1.0+20151226/translations/compton-conf_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>特殊効果の設定</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>影</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>影のぼかし半径</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>影の左のオフセット</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>影の上のオフセット</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>影の透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>影の色</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>ARGBウインドウの異常を直す</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>ウインドウ背後の影のマスクをゼロにする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>ドラッグアンドドロップのオブジェクトの影を描画しない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>ドックやパネルの影を描画しない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="113"/>
        <source>Enabled client-side shadows on windows</source>
        <translation>ウインドウのクライアント側の影を有効にする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>すべて整形済のウインドウに影を描画しない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>メニューの透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>非アクティブウインドウの透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>アクティブウインドウの透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>タイトルバーと境界の透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRenderバックエンド: アルファピクチャーのステップサイズ（増やすと、Xのリソース消費量が減ります）</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>非アクティブウインドウを暗くする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>ウインドウの透明度にあわせた暗さの調節をしない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>透明化ウインドウの背後をぼかす</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>透明化フレームを伴う不透明ウインドウの背後をぼかす</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>ウインドウの透明度にあわせたぼかし半径の調節をしない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>フェード</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>透明度の変化中にウインドウをフェードする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>フェード段階ごとの時間（ミリ秒）</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>フェードイン時の透明化のステップ値</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>フェードアウト時の透明化のステップ値</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>ウインドウの開閉時にフェードしない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="362"/>
        <source>Not implemented yet</source>
        <translation>未実装です</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="375"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="179"/>
        <source>About ComptonConf</source>
        <translation>ComptonConfについて</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="180"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Compton の設定ツール

Copyright (C) 2013
作者: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> compton-conf_0.14.0.orig.tar.xz: compton-conf-0.14.0/translations/compton-conf_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>特殊効果の設定</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>影</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>影のぼかし半径</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>影の左のオフセット</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>影の上のオフセット</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>影の透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>影の色</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>ARGBウインドウの異常を直す</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>ウインドウ背後の影のマスクをゼロにする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>ドラッグアンドドロップのオブジェクトの影を描画しない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>ドックやパネルの影を描画しない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>ウインドウのクライアント側の影を有効にする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>すべて整形済のウインドウに影を描画しない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>メニューの透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>非アクティブウインドウの透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>アクティブウインドウの透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>タイトルバーと境界の透明度</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRenderバックエンド: アルファピクチャーのステップサイズ（増やすと、Xのリソース消費量が減ります）</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>非アクティブウインドウを暗くする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>ウインドウの透明度にあわせた暗さの調節をしない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>透明化ウインドウの背後をぼかす</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>透明化フレームを伴う不透明ウインドウの背後をぼかす</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>ウインドウの透明度にあわせたぼかし半径の調節をしない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>フェード</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>透明度の変化中にウインドウをフェードする</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>フェード段階ごとの時間（ミリ秒）</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>フェードイン時の透明化のステップ値</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>フェードアウト時の透明化のステップ値</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>ウインドウの開閉時にフェードしない</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>ComptonConfについて</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Compton の設定ツール

Copyright (C) 2013
作者: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
